@@ -226,12 +226,10 @@ class ThemeForm(QtGui.QWizard, Ui_ThemeWizard):
 
     def onCurrentIdChanged(self, pageId):
         """
-        Detects Page changes and updates as approprate.
+        Detects Page changes and updates as appropriate.
         """
-        if self.page(pageId) == self.areaPositionPage:
-            self.setOption(QtGui.QWizard.HaveCustomButton1, True)
-        else:
-            self.setOption(QtGui.QWizard.HaveCustomButton1, False)
+        enabled = self.page(pageId) == self.areaPositionPage
+        self.setOption(QtGui.QWizard.HaveCustomButton1, enabled)
         if self.page(pageId) == self.previewPage:
             self.updateTheme()
             frame = self.thememanager.generateImage(self.theme)
