@@ -172,6 +172,11 @@ def _get_os_dir_path(dir_type):
             u'Library', u'Application Support', u'openlp')
     else:
         if dir_type == AppLocation.LanguageDir:
+            prefixes = [u'/usr/local', u'/usr']
+            for prefix in prefixes:
+                directory = os.path.join(prefix, u'share', u'openlp')
+                if os.path.exists(directory):
+                    return directory
             return os.path.join(u'/usr', u'share', u'openlp')
         if XDG_BASE_AVAILABLE:
             if dir_type == AppLocation.ConfigDir:
